@@ -1,7 +1,7 @@
 /*
  * configfile.h
  *
- * Copyright (c) 2ndQuadrant, 2010-2020
+ * Copyright (c) EnterpriseDB Corporation, 2010-2021
  *
  *
  * This program is free software: you can redistribute it and/or modify
@@ -50,6 +50,11 @@ typedef enum
 	CHECK_CONNECTION
 } ConnectionCheckType;
 
+typedef enum
+{
+	REPLICATION_TYPE_PHYSICAL
+} ReplicationType;
+
 typedef struct EventNotificationListCell
 {
 	struct EventNotificationListCell *next;
@@ -86,7 +91,8 @@ typedef enum
 	CONFIG_FAILOVER_MODE,
 	CONFIG_CONNECTION_CHECK_TYPE,
 	CONFIG_EVENT_NOTIFICATION_LIST,
-	CONFIG_TABLESPACE_MAPPING
+	CONFIG_TABLESPACE_MAPPING,
+    CONFIG_REPLICATION_TYPE
 } ConfigItemType;
 
 
@@ -103,6 +109,7 @@ typedef struct ConfigFileSetting
 		ConnectionCheckType *checktypeptr;
 		EventNotificationList *notificationlistptr;
 		TablespaceList *tablespacemappingptr;
+		ReplicationType *replicationtypeptr;
 	} val;
 	union {
 		int			intdefault;
@@ -110,6 +117,7 @@ typedef struct ConfigFileSetting
 		bool		booldefault;
 		failover_mode_opt failovermodedefault;
 		ConnectionCheckType checktypedefault;
+		ReplicationType replicationtypedefault;
 	} defval;
 	union {
 		int				intminval;
@@ -138,7 +146,7 @@ typedef struct
 	char		config_directory[MAXPGPATH];
 	char		pg_bindir[MAXPGPATH];
 	char		repmgr_bindir[MAXPGPATH];
-	int			replication_type;
+	ReplicationType	replication_type;
 
 	/* log settings */
 	char		log_level[MAXLEN];
@@ -198,6 +206,7 @@ typedef struct
 	int			primary_notification_timeout;
 	int			repmgrd_standby_startup_timeout;
 	char		repmgrd_pid_file[MAXPGPATH];
+	bool		repmgrd_exit_on_inactive_node;
 	bool		standby_disconnect_on_failover;
 	int			sibling_nodes_disconnect_timeout;
 	ConnectionCheckType connection_check_type;
@@ -241,7 +250,7 @@ typedef struct
 	/*
 	 * undocumented settings
 	 *
-	 * These settings are for testing or experimential features
+	 * These settings are for testing or experimental features
 	 * and may be changed without notice.
 	 */
 
@@ -356,6 +365,7 @@ const char *format_failover_mode(failover_mode_opt failover);
 void		exit_with_cli_errors(ItemList *error_list, const char *repmgr_command);
 
 void		print_item_list(ItemList *item_list);
+const char *print_replication_type(ReplicationType type);
 const char *print_connection_check_type(ConnectionCheckType type);
 char 	   *print_event_notification_list(EventNotificationList *list);
 char 	   *print_tablespace_mapping(TablespaceList *tablespacemappingptr);
@@ -364,6 +374,6 @@ extern bool modify_auto_conf(const char *data_dir, KeyValueList *items);
 
 extern bool ProcessRepmgrConfigFile(const char *config_file, const char *base_dir, ItemList *error_list, ItemList *warning_list);
 
-extern bool ProcessPostgresConfigFile(const char *config_file, const char *base_dir, KeyValueList *contents, ItemList *error_list, ItemList *warning_list);
+extern bool ProcessPostgresConfigFile(const char *config_file, const char *base_dir, bool strict, KeyValueList *contents, ItemList *error_list, ItemList *warning_list);
 
 #endif							/* _REPMGR_CONFIGFILE_H_ */
