@@ -3,7 +3,7 @@
  *
  * Implements witness actions for the repmgr command line utility
  *
- * Copyright (c) 2ndQuadrant, 2010-2020
+ * Copyright (c) EnterpriseDB Corporation, 2010-2021
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -560,7 +560,7 @@ void do_witness_help(void)
 
 	printf(_("WITNESS UNREGISTER\n"));
 	puts("");
-	printf(_("  \"witness register\" unregisters a witness node.\n"));
+	printf(_("  \"witness unregister\" unregisters a witness node.\n"));
 	puts("");
 	printf(_("  --dry-run                check prerequisites but don't make any changes\n"));
 	printf(_("  -F, --force              unregister when witness node not running\n"));
