@@ -1,6 +1,6 @@
 /*
  * repmgr-client-global.h
- * Copyright (c) 2ndQuadrant, 2010-2020
+ * Copyright (c) EnterpriseDB Corporation, 2010-2021
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -84,7 +84,7 @@ typedef struct
 	bool		fast_checkpoint;
 	bool		rsync_only;
 	bool		no_upstream_connection;
-	char		recovery_min_apply_delay[MAXLEN];
+	char		recovery_min_apply_delay[MAXLEN];	/* overrides setting in repmgr.conf */
 	char		replication_user[MAXLEN];
 	char		upstream_conninfo[MAXLEN];
 	bool		without_barman;
@@ -120,6 +120,7 @@ typedef struct
 	bool		missing_slots;
 	bool		has_passfile;
 	bool		replication_connection;
+	bool		repmgrd;
 	bool		data_directory_config;
 	bool		replication_config_owner;
 	bool		db_connection;
@@ -175,7 +176,7 @@ typedef struct
 		/* "node status" options */ \
 		false, \
 		/* "node check" options */ \
-		false, false, false, false, false, false, false, false,	false, false, false, false, \
+		false, false, false, false, false, false, false, false,	false, false, false, false, false, \
 		/* "node rejoin" options */ \
 		"", \
 		/* "node service" options */ \
@@ -219,7 +220,9 @@ typedef enum
 
 typedef enum
 {
+	JOIN_UNKNOWN = -1,
 	JOIN_SUCCESS,
+	JOIN_COMMAND_FAIL,
 	JOIN_FAIL_NO_PING,
 	JOIN_FAIL_NO_REPLICATION
 } standy_join_status;
@@ -282,8 +285,8 @@ extern void get_node_config_directory(char *config_dir_buf);
 extern void get_node_data_directory(char *data_dir_buf);
 extern void init_node_record(t_node_info *node_record);
 extern bool can_use_pg_rewind(PGconn *conn, const char *data_directory, PQExpBufferData *reason);
-extern void make_standby_signal_path(char *buf);
-extern bool write_standby_signal(void);
+extern void make_standby_signal_path(const char *data_dir, char *buf);
+extern bool write_standby_signal(const char *data_dir);
 
 extern bool create_replication_slot(PGconn *conn, char *slot_name, t_node_info *upstream_node_record, PQExpBufferData *error_msg);
 extern bool drop_replication_slot_if_exists(PGconn *conn, int node_id, char *slot_name);
